=======================================
Package Api Documentation for pylexique
=======================================


API Reference for the classes in pylexique.pylexique.py
-------------------------------------------------------

.. automodule:: pylexique.pylexique
    :member-order: bysource
    :members:
    :private-members:
    :show-inheritance:


API Reference for the classes in pylexique.utils.py
---------------------------------------------------

.. automodule:: pylexique.utils
    :member-order: bysource
    :members:
    :private-members:
    :inherited-members:
    :show-inheritance:
